@@ -33,7 +33,7 @@ void JSWriter::writeClass(UMLClassifier *c)
 {
     if (!c)
     {
-        logWarn0("JSWriter::writeClass: Cannot write class of NULL concept");
+        logWarn0("JSWriter::writeClass: Cannot write class of NULL classifier");
         return;
     }
 
